###################################################
### chunk number 1: meta
###################################################
options(keep.source = TRUE, width = 60)
meta <- packageDescription("RBrownie")


###################################################
### chunk number 2: LoadIn
###################################################
require(RBrownie)


###################################################
### chunk number 3: HelpNexus eval=FALSE
###################################################
## ?read.nexus 		# ape
## ?read.nexus.data  	# ape
## ?readNexus  		# phylobase


###################################################
### chunk number 4: InOutDemo eval=FALSE
###################################################
## data(parrot)  
## writeBrownie(parrot,file="parrotdata.nex")
## newparrot = readBrownie("parrotdata.nex")


###################################################
### chunk number 5: HelpNexus eval=FALSE
###################################################
## class(parrot)   	# list class
## length(parrot)		# == 10
## class(newparrot)   	# list class
## length(newparrot)	# == 10
## #
## class(parrot[[1]])  # brownie class representing the first tree in the list


###################################################
### chunk number 6: SeeClasses
###################################################
require(RBrownie,quietly=TRUE,warn.conflicts=FALSE)
phylo4d_slots = names(getSlots("phylo4d"))
phylo4d_ext_slots = names(getSlots("phylo4d_ext"))
brownie_slots = names(getSlots("brownie"))
phylo4d_slots
# set of differences between phylo4d and phyl4d_ext
setdiff(phylo4d_ext_slots,phylo4d_slots) 
# set of differences between phyl4d_ext and brownie
setdiff(brownie_slots,phylo4d_ext_slots)


###################################################
### chunk number 7: PlotFigOne
###################################################
require(phylobase)
# generate a random coalescent tree with 10 tips
ape_tree = rcoal(10)
#
# convert tree from 'phylo' (ape) to 'phylo4' (phylobase) format
phy_tree = as(ape_tree,"phylo4")
#
# generate junk data for the tips
sample_tipdata = runif(10)
#
# combine the phylogenetic tree and the sample data
phyd_tree = phylo4d(phy_tree,tip.data=sample_tipdata)
plot(phyd_tree)


###################################################
### chunk number 8: PlotFigTwo
###################################################
require(RBrownie)
ape_tree = rcoal(10,br=runif(9,5,15))
phy_tree = as(ape_tree,"phylo4")
#
# Discrete trait data:
# (Loosely simulate the evolution of a binary trait down a tree, 
#  choosing a random value for the tip and then changing 
#  the trait based on the the change matrix.)
#
phy_tree = reorder(phy_tree,order="preorder")
sample_binarydata = data.frame(rep(0,19)) # junk data
names(sample_binarydata) <- "hasTrait"
sample_binarydata[rootNode(phy_tree),1] = sample(c(0,1),1)  # choose root value
changemat = matrix(c(0.8,0.2,0.2,0.8),byrow=T,nrow=2) # prob. of changing on branch
sample_edges = integer(0)  # track edges where change occurs
for(i in seq(nrow(edges(phy_tree))))
{
	anc = edges(phy_tree)[i,1]
	desc = edges(phy_tree)[i,2]
	if(anc == 0)
		next

	newvalue = sample(c(0,1),1,prob=changemat[(sample_binarydata[anc,1]+1),])
	sample_binarydata[desc,1] = newvalue
	if( newvalue != sample_binarydata[anc,1] )
		sample_edges = append(sample_edges,i)
}
#
#
# Subnodes
# (put subnodes on the branches where the trait changed showing
#  where on the branch the change happened.  Note that the 
#  subnode data.frame must have the same structure as the 
#  parent data.frame)
#
tmpdata = as.integer(!sample_binarydata[edges(phy_tree)[sample_edges,2],1])
sample_subnodedata = data.frame(tmpdata)
names(sample_subnodedata) <- "hasTrait" 
#
# Position the subnodes along their respective branches
# using the fraction of the overall branch length.  In 
# this case, I'll put them near the middle of the branch.
sample_positions = runif(n=length(tmpdata),min=0.25,max=0.75) 
#
# Create the phylo4d_ext object, which first creates 
# a phylo4d object and then adds the subnodes to it.
#
# NOTE: any "extra" arguments (all.data) are passed 
# on to the phylo4d constructor via the ellipsis argument (...).
phyext_tree = phyext(phy_tree, 
			snode.data=sample_subnodedata, 
			snode.branch=edges(phy_tree)[sample_edges,], 
			snode.pos=sample_positions,
			all.data=sample_binarydata)

# nodes, subnodes, and branches without the "trait" (state 0) are colored black
# nodes, subnodes, and branches with the "trait" (state 1) are colored red
plot(phyext_tree,states=c(0,1),states.col=c("black","red"))


###################################################
### chunk number 9: PlotFigThree
###################################################
require(RBrownie)
data(parrot)
plot(parrot[[1]])


###################################################
### chunk number 10: PhyextAcc eval=FALSE
###################################################
## snid(phyext_tree)  # access subnode ids (not currently used)
## sndata(phyext_tree)  # access subnode data.frame (should reflect the parents d.f)
## snposition(phyext_tree)  # access subnode positions
## snbranch(phyext_tree)  # access branches subnodes are on
## showSubNodes(phyext_tree)  # print a textual representation of the subnodes


###################################################
### chunk number 11: PhyextAcc eval=FALSE
###################################################
## #
## ancestor.node = edges(phyext_tree)[1,1]
## descendant.node = edges(phyext_tree)[1,2]
## node.position = 0.5 
## node.data = data.frame(1) 
## names(node.data) <- "hasTrait"
## #
## phyext_tree = addSubNode(phyext_tree,
## 				ancestor.node,
## 				descendant.node,
## 				node.position,
## 				node.data)


###################################################
### chunk number 12: InOutDemoTwo eval=FALSE
###################################################
## data(parrot)
## write.nexus.simmap(parrot,file="parrottmp.nex")
## newparrot = read.nexus.simmap("parrottmp.nex")


###################################################
### chunk number 13: InheritsOne eval=FALSE
###################################################
## data(parrot)
## class(parrot[[1]]) # brownie
## inherits(parrot[[1]],"phylo4d_ext") # TRUE


###################################################
### chunk number 14: BrownieExample
###################################################
require(RBrownie)
data(parrot)
# How many columns are in the data.frame?
ncol(tdata(parrot[[1]]))
# What are their names?
names(tdata(parrot[[1]]))
# What are their types? 
datatypes(parrot[[1]])


###################################################
### chunk number 15: BrownieExample eval=FALSE
###################################################
## discData()
## contData()
## taxData()
## genericData() # undefined data (shouldn't be used)
## brownie.datatypes() # show all


###################################################
### chunk number 16: BrownieAddData
###################################################
#
require(RBrownie)
data(parrot)
#
# junk morphological data for tips
junkcont = runif((nNodes(parrot[[1]])+1),-10,10)
#
# junk discrete data for tips / nodes
junkdisc = sample(letters[1:4], length(junkcont) + nNodes(parrot[[1]]),replace=TRUE)
#
# (Note: if dataTypes argument is left out, the RBrownie will
#  attempt to guess the right datatype.  It is always better to specify.)
#
parrot_new = addData(parrot, tip.data=junkcont, dataTypes=contData())
parrot_new = addData(parrot_new, all.data=junkdisc, dataTypes=discData())
#
datatypes(parrot_new)


###################################################
### chunk number 17: BrownieAddTaxa eval=FALSE
###################################################
## hasTaxasets(parrot) # see if there are any taxasets
## taxasets(parrot) # return taxasets as data.frame
## #
## #
## # Use taxa names to indicate membership in a taxa set:
## all_sparisoma = grep("Sparisoma",tipLabels(parrot[[1]]),value=TRUE)
## taxasets(parrot,taxnames="sparisomas") <- all_sparisoma


###################################################
### chunk number 18: BrowniePlotTaxa
###################################################
require(RBrownie)
data(parrot)
plot.taxaset(parrot[[3]],2) # plot the second taxaset


###################################################
### chunk number 19: RateTestThree eval=FALSE
###################################################
## require(RBrownie)
## data(parrot)
## test.results = runCensored(parrot,taxset="intrajoint",reps=1000,charloop=T)
## summaryRatetest(test.results)


###################################################
### chunk number 20: RateTestFour
###################################################
require(RBrownie)
data(parrot)
taxaset.names(parrot) # we want to look at 'intrajoint', so use taxind=2
plot.censored(parrot[[2]],taxind=2)


###################################################
### chunk number 21: RateTestThree eval=FALSE
###################################################
## require(RBrownie)
## data(parrot)
## # brownie.models.continuous(T) will print out available models and descriptions
## test.results = runNonCensored(parrot,models=brownie.models.continuous()[1:2],
## 	treeloop=T,charloop=T)
## summaryCont(test.results)


###################################################
### chunk number 22: BrowniePlotNonCensored
###################################################
# run non-censored rate test
require(RBrownie)
data(parrot)
test.results = runNonCensored(parrot,models=brownie.models.continuous()[1:2],
	treeloop=T,charloop=T)
#
# Plot the evo rates from the BMS model
# use tree #1 and character #1
modname = "BMS"
tree = 1
char = 1
x = parrot[[tree]]
states = c(0,1)
state.cols = c(1,2)
line.widths = c(2,2)
state.ratename = c("Rate_in_state_0","Rate_in_state_1")
rowind = which(test.results$Tree==tree & 
	test.results$Char==char & 
	test.results$Model == modname)
junkrow = test.results[rowind,]
colinds = which(colnames(junkrow) %in% state.ratename)
#legends = paste(names(junkrow[colinds]),junkrow[colinds],sep=" = ")
legtext = c("State 0, ","State 1, ")
legends = sprintf("%0.3f",junkrow[colinds])
plot(x,states=states,states.col=state.cols,line.widths=line.widths,plot.points=T)
#
# Add legend
fontsize=10
boxSize = unit(fontsize, "points")
for(ii in seq(length(states)))
{
	yoff = unit( ((ii-1)*fontsize)+ ifelse(ii==1,0,2) ,"points")
#	grid.text(legends[ii],
	grid.text(bquote(.(legtext[ii])~sigma^2 == .(legends[ii])),
	x=unit(2, "mm"),
	y=unit(1, "npc") - unit(2, "mm") - yoff,
	just=c("left", "top"),
	gp=gpar(fontsize = fontsize))
	grid.rect(x=unit(2, "mm") - boxSize,
	y=unit(1, "npc") - unit(2, "mm") - boxSize - yoff,
	width = boxSize, height = boxSize,
	just = "bottom", gp = gpar(fill = state.cols[ii]))
}


###################################################
### chunk number 23: DiscreteFive
###################################################
require(RBrownie)
data(geospiza_ext)
junkrun=runDiscrete(geospiza_ext,
	models=c("nonrev","nonrev"),
	freqs=c("unif","equilib"),
	reconstruct=T)
#
# (View the reconstruction results for the first tree;
#  under the model 'nonrev' and using freq 'unif'):
plot(junkrun$trees[[1]])


###################################################
### chunk number 24: CustomOne eval=FALSE
###################################################
## help.search("add",package="RBrownie")


